@@ -6,6 +6,8 @@ requires qw(to_xml to_legacy_xml service query_path);
 
 sub url {
     my $self = shift;
+    my %args = @_;
+    my $format = $args{format} || "tab";
     my $xml;
     if ( $self->service->version < 2 ) {
         $xml = $self->to_legacy_xml;
@@ -16,7 +18,7 @@ sub url {
     my $uri        = URI->new($url);
     my %query_form = (
         query  => $xml,
-        format => 'tab',
+        format => $format,
     );
     $uri->query_form(%query_form);
     return $uri;
