@@ -102,10 +102,12 @@ sub results_with {
 
 sub url {
     my $self       = shift;
+    my %args = @_;
+    my $format = $args{format} || "tab";
     my $url        = $self->service_root . $self->templatequery_path;
     my $uri        = URI->new($url);
     my %query_form = (
-        format => 'tab',
+        format => $format,
         name   => $self->name,
     );
 
