@@ -1,10 +1,10 @@
 package Webservice::InterMine::ResultIterator;
 
 use Moose;
-use InterMine::TypeLibrary qw(HTTPCode NetHTTP PathList TextCSVXS);
+use InterMine::TypeLibrary 0.9500 qw(HTTPCode NetHTTP PathList TextCSV);
 use MooseX::Types::Moose qw(Str HashRef Bool Num GlobRef);
 use HTTP::Status qw(status_message);
-use Text::CSV_XS;
+use Text::CSV;
 use List::MoreUtils qw(zip);
 use Encode;
 
@@ -16,6 +16,30 @@ sub BUILD {
       unless ( $self->has_connection or $self->has_content );
 }
 
+=head1 Webservice::InterMine::ResultIterator - An object for iterating through result rows
+
+=head1 SYNOPSIS
+
+  my $query = get_query_from_somewhere();
+  my $iter = $query->result_iterator;
+  while (defined (my $hashref = $iter->hashref)) {
+    # do something with hashref
+  }
+
+=head1 DESCRIPTION
+
+This package provides objects for iterating through result sets.
+
+=head1 ATTRIBUTES
+
+=cut
+
+=head2 connection [ro]
+
+A Net::HTTP connection to the source of results
+
+=cut
+
 has connection => (
     is        => 'ro',
     isa       => NetHTTP,
@@ -23,12 +47,25 @@ has connection => (
     predicate => 'has_connection',
 );
 
+=head2 content [ro]
+
+A Glob with content. Can be a glob linked to any file-handle
+or other IO.
+
+=cut
+
 has content => (
     is        => 'ro',
     isa       => GlobRef,
     predicate => 'has_content',
 );
 
+=head2 error_code [ro]
+
+The error code from the request, if any.
+
+=cut
+
 has error_code => (
     is        => 'ro',
     isa       => HTTPCode,
@@ -36,6 +73,12 @@ has error_code => (
     predicate => 'has_code',
 );
 
+=head2 error_message [ro]
+
+The error message from the request, if any.
+
+=cut
+
 has error_message => (
     is      => 'ro',
     isa     => Str,
@@ -50,14 +93,26 @@ before qr/^error_/ => sub {
     }
 };
 
+=head2 csv [ro]
+
+The CSV parser used to parse CSV/TSV lines.
+
+=cut
+
 has csv => (
     is   => 'ro',
-    isa  => TextCSVXS,
+    isa  => TextCSV,
     lazy => 1,
     default =>
-      sub { Text::CSV_XS->new( { binary => 1, sep_char => "\t" } ) },
+      sub { Text::CSV->new( { binary => 1, sep_char => "\t", allow_loose_quotes => 1 } ) },
 );
 
+=head2 view_list [ro]
+
+The list of paths in the view for the query that was run.
+
+=cut
+
 has view_list => (
     is       => 'ro',
     isa      => PathList,
@@ -101,10 +156,10 @@ has is_finished => (
     is      => 'ro',
     isa     => Bool,
     default => 0,
-    handles => { conclude => 'set', },
+    handles => { close => 'set', },
 );
 
-after conclude => sub {
+after close => sub {
     my $self = shift;
     $self->connection->close;
 };
@@ -130,16 +185,36 @@ sub set_headers {
 
 ######## ERROR CHECKING METHODS
 
+=head1 METHODS 
+
+=head2 [Bool] is_success
+
+Returns true if the server responded with a success-y status.
+
+=cut
+
 sub is_success {
     my $self = shift;
     return HTTP::Status::is_success( $self->error_code );
 }
 
+=head2 [Bool] is_error
+
+Returns true if the server responded with an error-ish status.
+
+=cut
+
 sub is_error {
     my $self = shift;
     return HTTP::Status::is_error( $self->error_code );
 }
 
+=head2 [Str] status_line
+
+Returns a human readable status line.
+
+=cut
+
 sub status_line {
     my $self = shift;
     my $line = sprintf( "%s (%s): %s",
@@ -167,7 +242,7 @@ sub read_line {
         }
         $self->chunk_bytes_left( hex($chunksize) );
         if ( $self->chunk_bytes_left == 0 ) {    # EOF
-            $self->conclude;
+            $self->close;
             return undef;
         }
     }
@@ -191,6 +266,12 @@ sub read_line {
 
 ########## USER ACCESS METHODS
 
+=head2 [Str] string
+
+returns the next line as a string.
+
+=cut
+
 sub string {
     my $self = shift;
     my $line = $self->read_line;
@@ -201,6 +282,12 @@ sub string {
     return $line;
 }
 
+=head2 [Str] arrayref
+
+returns the next line as an arrayref.
+
+=cut
+
 sub arrayref {
     my $self = shift;
     my $line = $self->string or return;
@@ -208,6 +295,12 @@ sub arrayref {
     return $self->csv->getline($io);
 }
 
+=head2 [Str] hashref
+
+returns the next line as a hashref
+
+=cut
+
 sub hashref {
     my $self = shift;
     my $line = $self->string or return;
@@ -215,6 +308,12 @@ sub hashref {
     return $self->csv->getline_hr($io);
 }
 
+=head2 [List] all_lines( format )
+
+Returns all the lines, in the desired format (string/arrayref/hashref).
+
+=cut
+
 sub all_lines {
     my ( $self, $wanted ) = @_;
     confess
