@@ -36,10 +36,12 @@ use Webservice::InterMine::ResultIterator;
 use Net::HTTP;
 use URI;
 use LWP::UserAgent;
+use MIME::Base64;
 use MooseX::Types::Moose qw/Str/;
 use InterMine::TypeLibrary
   qw(Uri Model TemplateFactory SavedQueryFactory ListFactory);
 
+
 =head2 new( $url, [$user, $pass] )
 
 A service can be constructed directly by passing a webservice
@@ -53,11 +55,13 @@ login information in the form of a username and password.
 around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
+    my @build_args = @_;
     if ( @_ <= 3 and $_[0] ne 'root' ) {
         my %args;
-        $args{root} = shift if @_;
-        $args{user} = shift if @_;
-        $args{pass} = shift if @_;
+        for (qw/root user pass/) {
+            my $next = shift @build_args;
+            $args{$_} = $next if $next;
+        }
         return $class->$orig(%args);
     } else {
         return $class->$orig(@_);
@@ -95,11 +99,13 @@ has root => (
 has user => (
     is  => 'ro',
     isa => Str,
+    predicate => 'has_user',
 );
 
 has pass => (
     is  => 'ro',
     isa => Str,
+    predicate => 'has_pass',
 );
 
 =head2 new_query
@@ -226,11 +232,15 @@ has release => (
 
 # Returns a LWP::UserAgent suitable for getting and posting with
 sub agent {
+    my $self = shift;
     my $ua = LWP::UserAgent->new;
     $ua->env_proxy;
     $ua->agent(USER_AGENT);
+    if ($self->has_user and $self->has_pass) {
+        my $auth_string = join(':', $self->user, $self->pass);
+        $ua->default_header( Authorization => encode_base64($auth_string) );
+    }
 
-#    $ua->credentials($self->host.':80', $realm, $self->user, $self->pass);
     return $ua;
 }
 
